@@ -1,6 +1,6 @@
 use pyo3::{prelude::*, Python};
 use pyo3_stub_gen::derive::gen_stub_pyfunction;
-use statsig_rust::log_w;
+use statsig_rust::statsig_global::StatsigGlobal;
 use std::sync::atomic::{AtomicBool, Ordering};
 
 lazy_static::lazy_static! {
@@ -13,7 +13,11 @@ pub fn notify_python_shutdown() {
     PYTHON_RUNNING.store(false, Ordering::SeqCst);
 }
 
-const TAG: &str = "SafeGil";
+#[gen_stub_pyfunction]
+#[pyfunction]
+pub fn notify_python_fork() {
+    StatsigGlobal::reset();
+}
 
 pub struct SafeGil;
 
@@ -23,7 +27,7 @@ impl SafeGil {
         F: for<'py> FnOnce(Option<Python<'py>>) -> R,
     {
         if !PYTHON_RUNNING.load(Ordering::SeqCst) {
-            log_w!(TAG, "GIL Unavailable: Python interpreter is shutting down");
+            log_gil_unavailable();
 
             return f(None);
         }
@@ -31,3 +35,8 @@ impl SafeGil {
         Python::with_gil(move |py| f(Some(py)))
     }
 }
+
+fn log_gil_unavailable() {
+    // we do not use the logging framework here as it may recursively try access the GIL
+    eprintln!("StatsigSafeGil: GIL Unavailable. Python interpreter is shutting down");
+}
